﻿* Encoding: UTF-8.
/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIÓN DE LA EDUCACIÓN
/*             UNIDAD DE EVALUACIÓN DEL SISTEMA EDUCATIVO NACIONAL
/*             DIRECCIÓN GENERAL DE MEDICIÓN Y TRATAMIENTO DE DATOS
/*
/*                      DIRECCIÓN DE TRATAMIENTO DE DATOS
/*
/*_____________________________________________________________________________
/*
/*                                   EVOE-ECEA
/*                                  PREESCOLAR
/*
/*                              **** ESCUELAS  ****
/*
/*_____________________________________________________________________________
/*
/*
/*             SINTAXIS PARA ETIQUETAR LA TABLA DE DATOS DE ESCUELAS
/*                       EN FORMATO SPSS PARA ECEA00, 2017
/*_____________________________________________________________________________
/*
/*  La sintaxis etiqueta las variables así como sus valores y declara los
/*  valores perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para etiquetar la base de datos (tabla de datos) es necesario:
/*      1) Abrir la tabla de en formato SPSS y el archivo de sintaxis
/*      2) Ejecutar toda la sintaxis del archivo.
/*
/*  Al finalizar el ejecución del sintaxis, la tabla ECEA00_2017_Escuelas.SAV
/*  quedará etiquetada.
/*
/* CONTACTO:
/*
/*      Para mayor información o aclaración de dudas favor de contactar a la
/*      Dirección de Tratamiento de Datos
/*      Correo electrónico: analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 32025
/*      Domicilio: Av. Barranca del Muerto no. 341, 3er piso. Col. San José Insurgentes
/*                 Del. Benito Juárez. Ciudad de México
/*
/* FECHA DE LIBERACIÓN:  5 de abril de 2019
/*
/*  ****************************************************************************/




/***********************************************************************
/* Etiquetas de variables
/*
/**********************************************************************.

VARIABLE LABELS
       NACIONAL                   "Variable auxiliar para obtener promedios nacionales"
       ESCUELA                    "Identificador de la escuela"
       NIVEL                      "Nivel educativo"
       CAT_ESC                    "Clasificación de las escuelas según el cuestionario de director o encargado de dirección que le corresponde"
       ID_ENT                     "Entidad federativa (identificador numérico)"
       NOM_ENT                    "Entidad federativa"
       ID_TURNO                   "Identificador numérico del turno escolar"
       TURNO                      "Turno de la escuela"
       ID_PREESTRATO              "Identificador numérico del preestrato"
       PREESTRATO                 "Dominio de interés"
       W_FSCHWT                   "Peso muestral final de la escuela"
       D01a                       "¿De qué manera llega el agua a este preescolar? Red pública (agua corriente)"
       D01b                       "¿De qué manera llega el agua a este preescolar? Pozo o noria en el preescolar"
       D01c                       "¿De qué manera llega el agua a este preescolar? Pipa de agua"
       D01d                       "¿De qué manera llega el agua a este preescolar? Acarreo de agua (de alguna casa o construcción o de algún río, laguna, estanque u otro)"
       D01e                       "¿De qué manera llega el agua a este preescolar? Otra"
       D02                        "En este preescolar, ¿cuántos días de la semana escolar se dispone de agua?"
       D03                        "En este preescolar, ¿niñas y niños disponen de agua apta para beber, es decir, de garrafón, hervida, de bebederos o purificada por filtro?"
       D04                        "En este preescolar, ¿de qué manera llega el servicio de luz (energía eléctrica)?"
       D05                        "Durante el ciclo escolar 2017-2018, ¿en este preescolar se han realizado simulacros como preparación ante alguna contingencia (sismo, huracán, incendio, fuga de gas, balacera u otro)?"
       D06a                       "En este preescolar, ¿existen las siguientes medidas y recursos de seguridad? Extintores funcionando"
       D06b                       "En este preescolar, ¿existen las siguientes medidas y recursos de seguridad? Alarma sonora funcionando"
       D06c                       "En este preescolar, ¿existen las siguientes medidas y recursos de seguridad? Botiquín de primeros auxilios equipado"
       D06d                       "En este preescolar, ¿existen las siguientes medidas y recursos de seguridad? Señalamientos de seguridad como: “No entrar”, “Zona de seguridad”, “No empujar” u otros"
       D06e                       "En este preescolar, ¿existen las siguientes medidas y recursos de seguridad? Rutas o procedimientos de evacuación"
       D06f                       "En este preescolar, ¿existen las siguientes medidas y recursos de seguridad? Zona de seguridad o puntos de reunión identificados"
       D06g                       "En este preescolar, ¿existen las siguientes medidas y recursos de seguridad? Plan de protección civil"
       D06h                       "En este preescolar, ¿existen las siguientes medidas y recursos de seguridad? Comité de seguridad y emergencia escolar"
       D06i                       "En este preescolar, ¿existen las siguientes medidas y recursos de seguridad? Otra medida o recurso"
       D07a                       "Por la ubicación de este preescolar, ¿cuáles de las siguientes condiciones externas al plantel representan un riesgo o peligro para la seguridad de la comunidad escolar? Condiciones de riesgo por desastres naturales (deslav... (ver cuestionario .pdf)"
       D07b                       "Por la ubicación de este preescolar, ¿cuáles de las siguientes condiciones externas al plantel representan un riesgo o peligro para la seguridad de la comunidad escolar? Condiciones de riesgo por tránsito constante de vehíc... (ver cuestionario .pdf)"
       D07c                       "Por la ubicación de este preescolar, ¿cuáles de las siguientes condiciones externas al plantel representan un riesgo o peligro para la seguridad de la comunidad escolar? Condiciones de riesgo por contaminación (desechos tóx... (ver cuestionario .pdf)"
       D07d                       "Por la ubicación de este preescolar, ¿cuáles de las siguientes condiciones externas al plantel representan un riesgo o peligro para la seguridad de la comunidad escolar? Condiciones de riesgo por instalaciones de venta o tr... (ver cuestionario .pdf)"
       D07e                       "Por la ubicación de este preescolar, ¿cuáles de las siguientes condiciones externas al plantel representan un riesgo o peligro para la seguridad de la comunidad escolar? Condiciones de riesgo por inmuebles o espacios abando... (ver cuestionario .pdf)"
       D07f                       "Por la ubicación de este preescolar, ¿cuáles de las siguientes condiciones externas al plantel representan un riesgo o peligro para la seguridad de la comunidad escolar? Condiciones de riesgo por violencia social (lugares d... (ver cuestionario .pdf)"
       D07g                       "Por la ubicación de este preescolar, ¿cuáles de las siguientes condiciones externas al plantel representan un riesgo o peligro para la seguridad de la comunidad escolar? Otra condición"
       D08                        "En este ciclo escolar (2017-2018), ¿quién trajo los libros de texto gratuito al preescolar?"
       D08_1                      "En este ciclo escolar (2017-2018), ¿quién trajo las Unidades de Aprendizaje Autónomo al preescolar comunitario?"
       D08_2                      "En este ciclo escolar (2017-2018), ¿cuándo le entregaron la mayoría de los ejemplares de las Unidades de Aprendizaje Autónomo para las niñas y los niños?"
       D09                        "En este ciclo escolar (2017-2018), ¿cuándo le entregaron la mayoría de los ejemplares del libro Mi álbum. Preescolar para las niñas y los niños?"
       D10a                       "En este preescolar, ¿cómo se obtienen los materiales que las docentes requieren para las actividades con su grupo (para escribir, pintar, contar, modelar, dramatizar, etcétera)? Con la aportación de los padres de familia"
       D10b                       "En este preescolar, ¿cómo se obtienen los materiales que las docentes requieren para las actividades con su grupo (para escribir, pintar, contar, modelar, dramatizar, etcétera)? Las docentes aportan los materiales que se necesitan o la LEC"
       D10c                       "En este preescolar, ¿cómo se obtienen los materiales que las docentes requieren para las actividades con su grupo (para escribir, pintar, contar, modelar, dramatizar, etcétera)? Los aportan las autoridades educativas (secre... (ver cuestionario .pdf)"
       D10d                       "En este preescolar, ¿cómo se obtienen los materiales que las docentes requieren para las actividades con su grupo (para escribir, pintar, contar, modelar, dramatizar, etcétera)? Con el apoyo del gobierno federal, estatal o municipal"
       D10e                       "En este preescolar, ¿cómo se obtienen los materiales que las docentes requieren para las actividades con su grupo (para escribir, pintar, contar, modelar, dramatizar, etcétera)? Con apoyo de empresas o asociaciones civiles"
       D10f                       "En este preescolar, ¿cómo se obtienen los materiales que las docentes requieren para las actividades con su grupo (para escribir, pintar, contar, modelar, dramatizar, etcétera)? Otro medio"
       D11                        "Dentro de este preescolar, ¿se cuenta con acceso a Internet?"
       D12                        "En este preescolar, ¿cuántas computadoras en funcionamiento existen para el uso de niñas y niños?"
       D13                        "En este preescolar, ¿cuántos televisores en funcionamiento existen?"
       D14                        "En este preescolar, ¿cuántos DVD o reproductores de video en funcionamiento existen?"
       D15                        "En este preescolar, ¿cuántas grabadoras, estéreos o reproductores de audio en funcionamiento existen?"
       D16                        "En este preescolar, ¿cuántos proyectores o cañones en funcionamiento existen?"
       D17                        "En este preescolar, ¿se cuenta con equipo de sonido en funcionamiento (bocinas y micrófono, megáfono u otro)?"
       D18a                       "Al día de hoy, ¿cuántas niñas y niños están inscritos en este preescolar? niñas"
       D18b                       "Al día de hoy, ¿cuántas niñas y niños están inscritos en este preescolar? niños"
       D19                        "De las niñas y los niños inscritos en este preescolar, ¿cuántos hablan algún dialecto o lengua indígena?"
       D20                        "Al día de hoy, ¿cuántos grupos hay en este preescolar?"
       D21                        "En este preescolar, ¿hay niñas y niños con alguna discapacidad?"
       D22a                       "¿Cuántas niñas y niños hay con las siguientes discapacidades? Discapacidad motriz, es decir, que tienen dificultad permanente para caminar, moverse o controlar su postura"
       D22b                       "¿Cuántas niñas y niños hay con las siguientes discapacidades? Ceguera, es decir, que no ven"
       D22c                       "¿Cuántas niñas y niños hay con las siguientes discapacidades? Baja visión, es decir, que no ven bien ni con lentes o anteojos. No cuente a los niños que regularmente usan lentes"
       D22d                       "¿Cuántas niñas y niños hay con las siguientes discapacidades? Sordera diagnosticada por un especialista, es decir, que no oyen"
       D22e                       "¿Cuántas niñas y niños hay con las siguientes discapacidades? Baja audición diagnosticada por un especialista, es decir, que no oyen bien ni con auxiliar auditivo"
       D22f                       "¿Cuántas niñas y niños hay con las siguientes discapacidades? Discapacidad intelectual diagnosticada por un especialista, es decir, que presentan limitaciones significativas en el funcionamiento intelectual"
       D22g                       "¿Cuántas niñas y niños hay con las siguientes discapacidades? Trastorno del espectro autista diagnosticado por un especialista"
       D22h                       "¿Cuántas niñas y niños hay con las siguientes discapacidades? Trastorno por déficit de atención e hiperactividad (TDAH) diagnosticado por un especialista"
       D22i                       "¿Cuántas niñas y niños hay con las siguientes discapacidades? Problemas de aprendizaje diagnosticado por un especialista"
       D22j                       "¿Cuántas niñas y niños hay con las siguientes discapacidades? Problemas de lenguaje diagnosticado por un especialista"
       D22k                       "¿Cuántas niñas y niños hay con las siguientes discapacidades? Total de niñas y niños con alguna de las discapacidades anteriores. Si alguna niña o niño tiene más de una discapacidad, cuéntelo sólo una vez"
       D23                        "¿Este preescolar recibe apoyo de CAPEP, USAER, UDEEI u otro servicio público de educación especial?"
       D24                        "De las niñas y los niños que requieren el servicio de educación especial (CAPEP, USAER, UDEEI u otro), ¿cuántos de ellos lo reciben?"
       D25                        "Al inicio del ciclo escolar (agosto de 2017), ¿cuántas docentes frente a grupo había en este preescolar?"
       D26                        "Al día de hoy, ¿cuántas docentes frente a grupo hay en este preescolar?"
       D26_1                      "Al día de hoy, ¿cuántas docentes frente a grupo hay en este preescolar? o En esta comunidad, ¿cuántos LEC están asignados para atender a niñas y niños de educación preescolar?"
       D27                        "De agosto del 2017 a la fecha, ¿algunas docentes frente a grupo se han ausentado por más de dos semanas o se han ido definitivamente de este preescolar?"
       D28                        "De agosto de 2017 a la fecha, de las docentes frente a grupo que se han ausentado por más de dos semanas o se han ido definitivamente, ¿cuántas han sido sustituidas?"
       D29                        "De agosto de 2017 a la fecha, ¿cuál ha sido el tiempo máximo en el que se ha sustituido a las docentes que se han ausentado por más de dos semanas o se han ido definitivamente de este preescolar?"
       D30a                       "En este preescolar, ¿se cuenta con el siguiente personal docente adicional a la titular de grupo? Docente de Educación física"
       D30b                       "En este preescolar, ¿se cuenta con el siguiente personal docente adicional a la titular de grupo? Docente de Educación artística o equivalente"
       D30c                       "En este preescolar, ¿se cuenta con el siguiente personal docente adicional a la titular de grupo? Docente de Inglés u otra lengua extranjera"
       D30d                       "En este preescolar, ¿se cuenta con el siguiente personal docente adicional a la titular de grupo? Docente de Computación o equivalente"
       D31a                       "En este preescolar, ¿se cuenta con el siguiente personal de apoyo? Considere solamente a los que reciben un sueldo, independientemente de quien lo pague. Personal de apoyo en el aula (asistente educativo, nana o niñera u otro)"
       D31b                       "En este preescolar, ¿se cuenta con el siguiente personal de apoyo? Considere solamente a los que reciben un sueldo, independientemente de quien lo pague. Personal de apoyo a la dirección escolar (secretaria u otro)"
       D31c                       "En este preescolar, ¿se cuenta con el siguiente personal de apoyo? Considere solamente a los que reciben un sueldo, independientemente de quien lo pague. Personal de vigilancia o velador"
       D31d                       "En este preescolar, ¿se cuenta con el siguiente personal de apoyo? Considere solamente a los que reciben un sueldo, independientemente de quien lo pague. Personal para el aseo y limpieza del plantel (conserje, intendente u otro)"
       D31e                       "En este preescolar, ¿se cuenta con el siguiente personal de apoyo? Considere solamente a los que reciben un sueldo, independientemente de quien lo pague. Personal para servicios de alimentación (cocinera, nutriólogo u otro)"
       D32a                       "En este preescolar, ¿se cuenta con el apoyo del siguiente personal para trabajar con niñas o niños con discapacidad? Psicólogo"
       D32b                       "En este preescolar, ¿se cuenta con el apoyo del siguiente personal para trabajar con niñas o niños con discapacidad? Asesor técnico pedagógico de educación especial"
       D32c                       "En este preescolar, ¿se cuenta con el apoyo del siguiente personal para trabajar con niñas o niños con discapacidad? Docente de apoyo de educación especial o docente especializado"
       D32d                       "En este preescolar, ¿se cuenta con el apoyo del siguiente personal para trabajar con niñas o niños con discapacidad? Terapeuta de lenguaje o maestra de comunicación"
       D32e                       "En este preescolar, ¿se cuenta con el apoyo del siguiente personal para trabajar con niñas o niños con discapacidad? Especialista en psicomotricidad y juego"
       D32f                       "En este preescolar, ¿se cuenta con el apoyo del siguiente personal para trabajar con niñas o niños con discapacidad? Otro especialista"
       D33a                       "En general, ¿cuántas docentes realizan las siguientes acciones en el preescolar? Mantienen un trato respetuoso"
       D33b                       "En general, ¿cuántas docentes realizan las siguientes acciones en el preescolar? Tienen disposición para trabajar en equipo "
       D33c                       "En general, ¿cuántas docentes realizan las siguientes acciones en el preescolar? Comparten evidencias o dificultades de su trabajo"
       D33d                       "En general, ¿cuántas docentes realizan las siguientes acciones en el preescolar? Ofrecen o reciben retroalimentación sobre su trabajo "
       D33e                       "En general, ¿cuántas docentes realizan las siguientes acciones en el preescolar? Se descalifican u ofenden entre sí"
       D33f                       "En general, ¿cuántas docentes realizan las siguientes acciones en el preescolar? Imponen su punto de vista sobre el de otras docentes"
       D33g                       "En general, ¿cuántas docentes realizan las siguientes acciones en el preescolar? Discuten sus ideas de manera respetuosa en las reuniones"
       D33h                       "En general, ¿cuántas docentes realizan las siguientes acciones en el preescolar? Se agreden físicamente en el preescolar"
       D33i                       "En general, ¿cuántas docentes realizan las siguientes acciones en el preescolar? Se agreden verbalmente en el preescolar"
       D34                        "En general, ¿cuántas docentes la tratan de manera respetuosa?"
       D35                        "En una jornada regular de trabajo, ¿cuántas horas permanece el personal docente en este preescolar?"
       D36                        "En este preescolar, ¿de cuántos días es el calendario escolar?"
       D37                        "En las últimas cuatro semanas, además de las reuniones de Consejo Técnico, ¿cuántas reuniones ha tenido con su personal para abordar asuntos del preescolar?"
       D38a                       "En las últimas cuatro semanas, ¿se han suspendido las clases en este preescolar por alguno de los siguientes motivos? Alerta sanitaria (influenza, zika u otra)"
       D38b                       "En las últimas cuatro semanas, ¿se han suspendido las clases en este preescolar por alguno de los siguientes motivos? Condiciones de violencia o inseguridad en la zona"
       D38c                       "En las últimas cuatro semanas, ¿se han suspendido las clases en este preescolar por alguno de los siguientes motivos? Condiciones del clima o desastres naturales"
       D38d                       "En las últimas cuatro semanas, ¿se han suspendido las clases en este preescolar por alguno de los siguientes motivos? Festividades o tradiciones de la comunidad"
       D38e                       "En las últimas cuatro semanas, ¿se han suspendido las clases en este preescolar por alguno de los siguientes motivos? Reuniones de trabajo fuera del preescolar"
       D38f                       "En las últimas cuatro semanas, ¿se han suspendido las clases en este preescolar por alguno de los siguientes motivos? Actividad sindical"
       D38g                       "En las últimas cuatro semanas, ¿se han suspendido las clases en este preescolar por alguno de los siguientes motivos? Otro motivo"
       D38h                       "En las últimas cuatro semanas, ¿se han suspendido totalmente las clases en este preescolar por alguno de los siguientes motivos? Trámites ante alguna instancia"
       D38i                       "En las últimas cuatro semanas, ¿se han suspendido totalmente las clases en este preescolar por alguno de los siguientes motivos? Asuntos personales de la docente o LEC"
       D38j                       "En las últimas cuatro semanas, ¿se han suspendido totalmente las clases en este preescolar por alguno de los siguientes motivos? Comisión laboral"
       D38k                       "En las últimas cuatro semanas, ¿se han suspendido totalmente las clases en este preescolar por alguno de los siguientes motivos? Enfermedad o accidente de la docenteo LEC"
       D38l                       "En las últimas cuatro semanas, ¿se han suspendido totalmente las clases en este preescolar por alguno de los siguientes motivos? Curso de actualización"
       D39                        "En las últimas cuatro semanas, ¿cuántos días se han suspendido totalmente las clases en este preescolar?"
       D40a                       "Aproximadamente, ¿cuántos padres de familia participan en las siguientes actividades del preescolar? Apoyan en las actividades de aprendizaje de su hija o hijo en casa o en la escuela"
       D40b                       "Aproximadamente, ¿cuántos padres de familia participan en las siguientes actividades del preescolar? Participan en eventos culturales o recreativos del preescolar"
       D40c                       "Aproximadamente, ¿cuántos padres de familia participan en las siguientes actividades del preescolar? Asisten a reuniones que convoca el preescolar para la toma de decisiones"
       D40d                       "Aproximadamente, ¿cuántos padres de familia participan en las siguientes actividades del preescolar? Realizan acciones de limpieza en el preescolar"
       D40e                       "Aproximadamente, ¿cuántos padres de familia participan en las siguientes actividades del preescolar? Realizan acciones de mantenimiento en el preescolar como cortar el pasto, pintar algún espacio escolar, hacer reparaciones, entre otras"
       D40f                       "Aproximadamente, ¿cuántos padres de familia participan en las siguientes actividades del preescolar? Dan apoyo económico al preescolar"
       D40g                       "Aproximadamente, ¿cuántos padres de familia participan en las siguientes actividades del preescolar? Aportan materiales de limpieza"
       D40h                       "Aproximadamente, ¿cuántos padres de familia participan en las siguientes actividades del preescolar? Aportan materiales de construcción"
       D41                        "En este preescolar, ¿se cuenta con programas de atención a padres de familia (escuela para padres, pláticas o talleres sobre el desarrollo y trato a niñas y niños u otro)?"
       D42a                       "En este preescolar, ¿se cuenta con reglas, normas o acuerdos para regular los comportamientos de la comunidad escolar, es decir, reglamento escolar?"
       D42b                       "En este preescolar, ¿con cuáles de los siguientes reglamentos se cuenta? Reglamento del salón de clases: Contiene las reglas, normas o los acuerdos que regulan solamente las actividades y los comportamientos ... (ver cuestionario .pdf)"
       D43a                       "¿Cuáles de los siguientes aspectos se incluyen en el o los reglamentos de este preescolar? Fomento de valores como respetar, compartir, apoyar u otro"
       D43b                       "¿Cuáles de los siguientes aspectos se incluyen en el o los reglamentos de este preescolar? Acciones para el cuidado de otras personas"
       D43c                       "¿Cuáles de los siguientes aspectos se incluyen en el o los reglamentos de este preescolar? Indicaciones para conservar el orden en el preescolar"
       D43d                       "¿Cuáles de los siguientes aspectos se incluyen en el o los reglamentos de este preescolar? Presentación, arreglo y aseo personal de niñas y niños"
       D43e                       "¿Cuáles de los siguientes aspectos se incluyen en el o los reglamentos de este preescolar? Hábitos de cortesía"
       D43f                       "¿Cuáles de los siguientes aspectos se incluyen en el o los reglamentos de este preescolar? Aspectos sobre los que niñas y niños deben solicitar permiso"
       D43g                       "¿Cuáles de los siguientes aspectos se incluyen en el o los reglamentos de este preescolar? Conductas que se deben evitar en el preescolar"
       D43h                       "¿Cuáles de los siguientes aspectos se incluyen en el o los reglamentos de este preescolar? Acciones para cuidar el mobiliario y espacios comunes del preescolar"
       D43i                       "¿Cuáles de los siguientes aspectos se incluyen en el o los reglamentos de este preescolar? Acciones para el cuidado del medio ambiente"
       D43j                       "¿Cuáles de los siguientes aspectos se incluyen en el o los reglamentos de este preescolar? Procesos de evaluación e información sobre los aprendizajes de niñas y niños"
       D43k                       "¿Cuáles de los siguientes aspectos se incluyen en el o los reglamentos de este preescolar? Asistencia de los padres de familia a reuniones"
       D43l                       "¿Cuáles de los siguientes aspectos se incluyen en el o los reglamentos de este preescolar? Asistencia y puntualidad"
       D43m                       "¿Cuáles de los siguientes aspectos se incluyen en el o los reglamentos de este preescolar? Control de acceso de padres de familia y visitantes al preescolar"
       D43n                       "¿Cuáles de los siguientes aspectos se incluyen en el o los reglamentos de este preescolar? Aportaciones y apoyos de los padres de familia al preescolar"
       D43o                       "¿Cuáles de los siguientes aspectos se incluyen en el o los reglamentos de este preescolar? Colaboración de las familias en actividades relacionadas con el aprendizaje de niñas y niños"
       D43p                       "¿Cuáles de los siguientes aspectos se incluyen en el o los reglamentos de este preescolar? Convivencia y relaciones entre padres de familia, niñas y niños, y docentes"
       D43q                       "¿Cuáles de los siguientes aspectos se incluyen en el o los reglamentos de este preescolar? Cuidado de la salud y prevención de riesgos sanitarios en el preescolar"
       D43r                       "¿Cuáles de los siguientes aspectos se incluyen en el o los reglamentos de este preescolar? Otro aspecto"
       D44a                       "Desde el ciclo escolar 2016-2017 hasta el día de hoy, ¿este preescolar ha recibido apoyo de alguno de los siguientes programas? Programa Escuelas al CIEN"
       D44b                       "Desde el ciclo escolar 2016-2017 hasta el día de hoy, ¿este preescolar ha recibido apoyo de alguno de los siguientes programas? Programa Nacional de Convivencia Escolar"
       D44c                       "Desde el ciclo escolar 2016-2017 hasta el día de hoy, ¿este preescolar ha recibido apoyo de alguno de los siguientes programas? Programa Escuelas de Tiempo Completo"
       D44d                       "Desde el ciclo escolar 2016-2017 hasta el día de hoy, ¿este preescolar ha recibido apoyo de alguno de los siguientes programas? Programa para la Inclusión y la Equidad Educativa"
       D44e                       "Desde el ciclo escolar 2016-2017 hasta el día de hoy, ¿este preescolar ha recibido apoyo de alguno de los siguientes programas? Programa de Fortalecimiento a la Calidad de la Educación Básica"
       D44f                       "Desde el ciclo escolar 2016-2017 hasta el día de hoy, ¿este preescolar ha recibido apoyo de alguno de los siguientes programas? Programa de la Reforma Educativa"
       D44g                       "Desde el ciclo escolar 2016-2017 hasta el día de hoy, ¿este preescolar ha recibido apoyo de alguno de los siguientes programas? Otro programa"
       D45                        "Durante el ciclo escolar 2017-2018, ¿hay niñas o niños que han faltado cinco días o más en un mes?"
       D46a                       "Durante el ciclo escolar 2017-2018, ¿se han realizado las siguientes acciones con los padres de familia de niñas y niños que han faltado cinco días o más al mes? Se platica con ellos sobre la importancia del preescolar y la... (ver cuestionario .pdf)"
       D46b                       "Durante el ciclo escolar 2017-2018, ¿se han realizado las siguientes acciones con los padres de familia de niñas y niños que han faltado cinco días o más al mes? Se indagan las causas de las inasistencias con los padres de f... (ver cuestionario .pdf)"
       D46c                       "Durante el ciclo escolar 2017-2018, ¿se han realizado las siguientes acciones con los padres de familia de niñas y niños que han faltado cinco días o más al mes? Se les informa sobre becas y apoyos económicos para que su hi... (ver cuestionario .pdf)"
       D46d                       "Durante el ciclo escolar 2017-2018, ¿se han realizado las siguientes acciones con los padres de familia de niñas y niños que han faltado cinco días o más al mes? Se canalizan a las instancias correspondientes cuando la sit... (ver cuestionario .pdf)"
       D46e                       "Durante el ciclo escolar 2017-2018, ¿se han realizado las siguientes acciones con los padres de familia de niñas y niños que han faltado cinco días o más al mes? Se orienta a los padres de familia para que en casa realicen ... (ver cuestionario .pdf)"
       D46f                       "Durante el ciclo escolar 2017-2018, ¿se han realizado las siguientes acciones con los padres de familia de niñas y niños que han faltado cinco días o más al mes? Otras acciones"
       D47                        "Durante el ciclo escolar 2017-2018, ¿este preescolar ha contado con el Programa de Desayunos Escolares del DIF?"
       D48a                       "Durante el ciclo escolar 2017-2018, ¿cuáles de las siguientes acciones se han realizado para promover la alimentación saludable de niñas y niños de este preescolar? Impartir pláticas a los padres de familia sobre la alimentación saludable"
       D48b                       "Durante el ciclo escolar 2017-2018, ¿cuáles de las siguientes acciones se han realizado para promover la alimentación saludable de niñas y niños de este preescolar? Proporcionar menús balanceados en el servicio de alimentación en el preescolar"
       D48c                       "Durante el ciclo escolar 2017-2018, ¿cuáles de las siguientes acciones se han realizado para promover la alimentación saludable de niñas y niños de este preescolar? Explicar a niñas y niños cómo debe ser una alimentaci... (ver cuestionario .pdf)"
       D48d                       "Durante el ciclo escolar 2017-2018, ¿cuáles de las siguientes acciones se han realizado para promover la alimentación saludable de niñas y niños de este preescolar? Solicitar a los padres de familia que envíen refrigerios saludables"
       D48e                       "Durante el ciclo escolar 2017-2018, ¿cuáles de las siguientes acciones se han realizado para promover la alimentación saludable de niñas y niños de este preescolar? Otra acción"
       D49a                       "Durante el ciclo escolar 2017-2018, ¿se han realizado las siguientes acciones para la promoción de la salud de niñas y niños de este preescolar? Pláticas a los padres de familia o tutores sobre el cuidado de la salud de sus hijas o hijos en casa"
       D49b                       "Durante el ciclo escolar 2017-2018, ¿se han realizado las siguientes acciones para la promoción de la salud de niñas y niños de este preescolar? Campañas de vacunación en conjunto con el Sector Salud"
       D49c                       "Durante el ciclo escolar 2017-2018, ¿se han realizado las siguientes acciones para la promoción de la salud de niñas y niños de este preescolar? Campañas sobre nutrición, salud visual y dental, entre otras"
       D49d                       "Durante el ciclo escolar 2017-2018, ¿se han realizado las siguientes acciones para la promoción de la salud de niñas y niños de este preescolar? Distribución a los padres de familia de carteles, folletos u otro material i... (ver cuestionario .pdf)"
       D49e                       "Durante el ciclo escolar 2017-2018, ¿se han realizado las siguientes acciones para la promoción de la salud de niñas y niños de este preescolar? Otra acción"
       D50                        "Usted es:"
       D51                        "¿Cuántos años cumplidos tiene usted?"
       D52                        "De acuerdo con su cultura, ¿usted se considera indígena?"
       D53                        "¿Usted habla algún dialecto o lengua indígena?"
       D54                        "De acuerdo con su cultura, historia y tradiciones, ¿usted se considera negra, es decir, afromexicana o afrodescendiente? Se incluye el término “negra” debido a que una parte de la población afrodescendiente se reconoce de esa manera."
       D55                        "¿Cuál es el máximo nivel de estudios del que obtuvo certificado o título?"
       D56                        "¿En qué tipo de licenciatura tiene certificado o título?"
       D57                        "¿Cuál de los siguientes estudios cursa en la actualidad?"
       D57_1                      "¿Cuál de los siguientes estudios cursa en la actualidad?"
       D58                        "¿Cuántos años ha trabajado como docente frente a grupo en escuelas públicas o privadas?"
       D59                        "¿Cuántos años ha trabajado como directora o encargada de la dirección en escuelas públicas o privadas? Cuente todos los años que ha sido encargada, comisionada o con nombramiento de directora."
       D60                        "Incluyendo este preescolar, ¿en cuántas escuelas se ha desempeñado como directora o encargada de la dirección? Cuente todas las escuelas en las que ha sido encargada, comisionada o con nombramiento de directora aún cuando estuviera frente a grupo."
       D61                        "En este preescolar, ¿cuántos años ha sido directora? Cuente todos los años que ha sido encargada, comisionada o con nombramiento de directora."
       D62                        "Al día de hoy, en este preescolar, ¿cuál es su nombramiento o cargo?"
       D63                        "En este preescolar, ¿usted es directora frente a grupo?"
       D64                        "¿Usted cursó algún diplomado, especialidad u otro estudio formal sobre dirección escolar?"
       D65a                       "En los dos últimos años, ¿ha tomado cursos sobre los siguientes temas? Gestión escolar"
       D65b                       "En los dos últimos años, ¿ha tomado cursos sobre los siguientes temas? Normatividad de la escuela"
       D65c                       "En los dos últimos años, ¿ha tomado cursos sobre los siguientes temas? Promoción de la participación de la comunidad escolar"
       D65d                       "En los dos últimos años, ¿ha tomado cursos sobre los siguientes temas? Organización y funcionamiento de la escuela"
       D65e                       "En los dos últimos años, ¿ha tomado cursos sobre los siguientes temas? Administración o control escolar"
       D65f                       "En los dos últimos años, ¿ha tomado cursos sobre los siguientes temas? Vinculación con la comunidad"
       D65g                       "En los dos últimos años, ¿ha tomado cursos sobre los siguientes temas? Convivencia escolar o prevención de la violencia"
       D65h                       "En los dos últimos años, ¿ha tomado cursos sobre los siguientes temas? Aspectos pedagógicos y didácticos"
       D65i                       "En los dos últimos años, ¿ha tomado cursos sobre los siguientes temas? Atención a la diversidad"
       D65j                       "En los dos últimos años, ¿ha tomado cursos sobre los siguientes temas? Otro tema"
       D66                        "De agosto de 2017 a la fecha, ¿la supervisora la ha visitado en este preescolar para ofrecerle asesoría?"
       D67a                       "De agosto de 2017 a la fecha, durante las visitas de la supervisora al preescolar, ¿en cuáles de los siguientes temas ha recibido asesoría de la supervisora? Trabajo con el Programa de Educación Preescolar"
       D67b                       "De agosto de 2017 a la fecha, durante las visitas de la supervisora al preescolar, ¿en cuáles de los siguientes temas ha recibido asesoría de la supervisora? Llenado de documentos de control escolar y estadísticas oficiales"
       D67c                       "De agosto de 2017 a la fecha, durante las visitas de la supervisora al preescolar, ¿en cuáles de los siguientes temas ha recibido asesoría de la supervisora? Gestión de recursos para mejorar el plantel en cuanto a infraestructura y equipamiento"
       D67d                       "De agosto de 2017 a la fecha, durante las visitas de la supervisora al preescolar, ¿en cuáles de los siguientes temas ha recibido asesoría de la supervisora? Operación de los programas en los que participa el preescolar"
       D67e                       "De agosto de 2017 a la fecha, durante las visitas de la supervisora al preescolar, ¿en cuáles de los siguientes temas ha recibido asesoría de la supervisora? Atención a niñas y niños con discapacidad"
       D67f                       "De agosto de 2017 a la fecha, durante las visitas de la supervisora al preescolar, ¿en cuáles de los siguientes temas ha recibido asesoría de la supervisora? Atención a la diversidad cultural y lingüística"
       D67g                       "De agosto de 2017 a la fecha, durante las visitas de la supervisora al preescolar, ¿en cuáles de los siguientes temas ha recibido asesoría de la supervisora? Participación de los padres de familia en las actividades del preescolar"
       D67h                       "De agosto de 2017 a la fecha, durante las visitas de la supervisora al preescolar, ¿en cuáles de los siguientes temas ha recibido asesoría de la supervisora? Prevención y atención de incidentes laborales del personal del preescolar"
       D67i                       "De agosto de 2017 a la fecha, durante las visitas de la supervisora al preescolar, ¿en cuáles de los siguientes temas ha recibido asesoría de la supervisora? Asesoría a docentes para que realicen su trabajo en el salón de clases"
       D67j                       "De agosto de 2017 a la fecha, durante las visitas de la supervisora al preescolar, ¿en cuáles de los siguientes temas ha recibido asesoría de la supervisora? Integración de docentes que ingresan al preescolar"
       D67k                       "De agosto de 2017 a la fecha, durante las visitas de la supervisora al preescolar, ¿en cuáles de los siguientes temas ha recibido asesoría de la supervisora? Otro tema"
       G01                        "¿El edificio que actualmente ocupa este plantel educativo fue construido para ser un preescolar?"
       G02                        "¿El preescolar cuenta con control de entrada y salida de personas, es decir, se cuenta con vigilante o se cierran las puertas en horas de clase?"
       G03                        "¿El preescolar cuenta con barda o cerco perimetral?"
       G04a                       "La barda o cerco perimetral del preescolar, ¿está hecho de los siguientes materiales? Tabique, ladrillo, block, piedra, cantera, cemento o concreto"
       G04b                       "La barda o cerco perimetral del preescolar, ¿está hecho de los siguientes materiales? Malla ciclónica o de alambre de púas"
       G04c                       "La barda o cerco perimetral del preescolar, ¿está hecho de los siguientes materiales? Reja metálica"
       G04d                       "La barda o cerco perimetral del preescolar, ¿está hecho de los siguientes materiales? Madera"
       G04e                       "La barda o cerco perimetral del preescolar, ¿está hecho de los siguientes materiales? Otro material"
       G05a                       "¿Cuáles de las siguientes instalaciones existen en este preescolar para facilitar el acceso y desplazamiento de personas con discapacidad? Rampas para el acceso y la circulación"
       G05b                       "¿Cuáles de las siguientes instalaciones existen en este preescolar para facilitar el acceso y desplazamiento de personas con discapacidad? Andadores o pasillos adecuados para el acceso a los espacios escolares"
       G05c                       "¿Cuáles de las siguientes instalaciones existen en este preescolar para facilitar el acceso y desplazamiento de personas con discapacidad? Puertas amplias para el acceso en silla de ruedas"
       G06a                       "Indique cuáles de los siguientes espacios existen en este preescolar. Patio"
       G06b                       "Indique cuáles de los siguientes espacios existen en este preescolar. Área de juegos (columpios, resbaladillas, pasamanos, llantas, sube y baja u otro)"
       G06c                       "Indique cuáles de los siguientes espacios existen en este preescolar. Oficina de dirección"
       G06d                       "Indique cuáles de los siguientes espacios existen en este preescolar. Sala de maestros"
       G06e                       "Indique cuáles de los siguientes espacios existen en este preescolar. Salón de usos múltiples (para actividades artísticas, recreativas o culturales)"
       G06f                       "Indique cuáles de los siguientes espacios existen en este preescolar. Aula de medios (salón de cómputo)"
       G06g                       "Indique cuáles de los siguientes espacios existen en este preescolar. Comedor o área para consumo de alimentos"
       G06h                       "Indique cuáles de los siguientes espacios existen en este preescolar. Cocina o lugar para preparar alimentos"
       G06i                       "Indique cuáles de los siguientes espacios existen en este preescolar. Dormitorio para la docente o Líder de Educación Comunitaria (LEC)"
       G07a                       "Indique cuáles de los siguientes espacios disponen de servicio de luz (energía eléctrica). Oficina de dirección"
       G07b                       "Indique cuáles de los siguientes espacios disponen de servicio de luz (energía eléctrica). Sala de maestros"
       G07c                       "Indique cuáles de los siguientes espacios disponen de servicio de luz (energía eléctrica). Salón de usos múltiples (para actividades artísticas, recreativas o culturales)"
       G07d                       "Indique cuáles de los siguientes espacios disponen de servicio de luz (energía eléctrica). Aula de medios (salón de cómputo)"
       G08a                       "Lea con cuidado los siguientes criterios y valore las condiciones de limpieza de cada uno de los espacios por los que se le solicita información. Patio"
       G08b                       "Lea con cuidado los siguientes criterios y valore las condiciones de limpieza de cada uno de los espacios por los que se le solicita información. Áreas de juego (columpios, resbaladillas, pasamanos, llantas, sube y baja u otro)"
       G08c                       "Lea con cuidado los siguientes criterios y valore las condiciones de limpieza de cada uno de los espacios por los que se le solicita información. Salón de usos múltiples (para actividades artísticas, recreativas o culturales)"
       G08d                       "Lea con cuidado los siguientes criterios y valore las condiciones de limpieza de cada uno de los espacios por los que se le solicita información. Cocina o lugar para preparar alimentos"
       G08e                       "Lea con cuidado los siguientes criterios y valore las condiciones de limpieza de cada uno de los espacios por los que se le solicita información. Comedor o área para consumo de alimentos"
       G09                        "En este preescolar, ¿existe un espacio físico específico donde se ubica la biblioteca escolar?"
       G10a                       "En la biblioteca escolar, ¿existe el siguiente mobiliario? Sillas o mobiliario para sentarse"
       G10b                       "En la biblioteca escolar, ¿existe el siguiente mobiliario? Mesas"
       G10c                       "En la biblioteca escolar, ¿existe el siguiente mobiliario? Estantes para organizar o mostrar los libros"
       G11                        "La biblioteca escolar, ¿dispone de servicio de luz (energía eléctrica)?"
       G12                        "En este preescolar, ¿en cuántos salones se imparten clases?"
       G13                        "En este preescolar, ¿cuántos salones tienen paredes o muros?"
       G14                        "¿De qué material están construidas las paredes o los muros de más de la mitad de los salones de este preescolar?"
       G15                        "En este preescolar, ¿cuántos salones tienen techo?"
       G16                        "¿De qué material está construido el techo de más de la mitad de los salones de este preescolar?"
       G17                        "¿De qué material es el piso de más de la mitad de los salones de este preescolar?"
       G18                        "¿Qué tan limpios están la mayoría de los salones de clases?"
       G19                        "En este preescolar, ¿hay agua para que niñas y niños se laven las manos?"
       G20                        "En este preescolar, ¿cuántos lavamanos para niñas y niños están en funcionamiento, es decir, tienen agua y desagüe?"
       G21                        "En este preescolar, en total, ¿cuántos servicios sanitarios como tazas, inodoros, excusados o letrinas están en funcionamiento?"
       G22                        "De los servicios sanitarios como tazas, inodoros, excusados o letrinas que están en funcionamiento, ¿cuántos son para uso exclusivo de docentes o adultos, es decir, no entran niñas o niños de manera regular?"
       G23                        "De los servicios sanitarios como tazas, inodoros, excusados o letrinas que están en funcionamiento, ¿cuántos son para uso exclusivo de niñas y niños, es decir, no entran adultos de manera regular?"
       G24                        "De los servicios sanitarios como tazas, inodoros, excusados o letrinas que están en funcionamiento para uso de niñas y niños, ¿están separadas por sexo?"
       G25                        "En este preescolar, ¿hay agua para los servicios sanitarios como tazas, inodoros, excusados o letrinas que están en funcionamiento para uso de niñas y niños?"
       G26                        "En este preescolar, ¿cuál es el tipo de instalación que tienen los servicios sanitarios como tazas, inodoros excusados o letrinas?"
       G27                        "¿Hay sanitarios amplios y con agarraderas que faciliten el acceso a niñas y niños en silla de ruedas?"
       G28                        "¿Hay sanitarios amplios y con agarraderas que faciliten el acceso a docentes y adultos en silla de ruedas?"
       G29                        "En este preescolar, ¿qué tan limpio está el servicio sanitario?"
       G30a                       "¿Cuáles de los siguientes problemas tiene actualmente este preescolar? Vidrios rotos o estrellados"
       G30b                       "¿Cuáles de los siguientes problemas tiene actualmente este preescolar? Instalación hidráulica en mal estado (fugas de agua, tubería oxidada u otro)"
       G30c                       "¿Cuáles de los siguientes problemas tiene actualmente este preescolar? Instalación eléctrica en mal estado o sin protección (cables sin recubrimiento, contactos sin protectores o que no funcionan, aparatos eléctricos al ... (ver cuestionario .pdf)"
       G30d                       "¿Cuáles de los siguientes problemas tiene actualmente este preescolar? Instalación de gas en mal estado (fugas de gas, instalación al alcance de niñas y niños u otro)"
       G30e                       "¿Cuáles de los siguientes problemas tiene actualmente este preescolar? Muros o bardas en mal estado (agrietados, con exceso de humedad, inclinados, derruidos, incompletos u otro)"
       G30f                       "¿Cuáles de los siguientes problemas tiene actualmente este preescolar? Techo(s) en mal estado (agrietados, con exceso de humedad, derruidos u otro)"
       G30g                       "¿Cuáles de los siguientes problemas tiene actualmente este preescolar? Piso(s) en mal estado (socavones, losa rota o floja, incompleto, disparejo, terreno irregular u otro)"
       G30h                       "¿Cuáles de los siguientes problemas tiene actualmente este preescolar? Barandales en mal estado (roto, incompleto, insuficiente, con baja altura, barrotes muy separados o de materiales frágiles u otro)"
       G30i                       "¿Cuáles de los siguientes problemas tiene actualmente este preescolar? Escaleras en mal estado que usen niñas y niños (sin pasamanos, escalones en mal estado, escalones sin antiderrapante u otro)"
       G30j                       "¿Cuáles de los siguientes problemas tiene actualmente este preescolar? Área de juego en mal estado que represente riesgo para niñas y niños (columpios o resbaladillas rotos, oxidados u otro)"
       G31a                       "¿Cuáles de los siguientes problemas identificó en el preescolar? Presencia de materiales tóxicos como detergente, cloro, alcohol, agua oxigenada u otro a los que niñas y niños pueden acceder en las aulas, los baños u otros espacios escolares"
       G31b                       "¿Cuáles de los siguientes problemas identificó en el preescolar? Obras de construcción o remodelación dentro del preescolar sin protección a las que niñas y niños pueden acceder"
       G31c                       "¿Cuáles de los siguientes problemas identificó en el preescolar? Pasto o maleza dentro del preescolar sin podar que representen riesgo por estancamiento de agua o anidación de animales"
       G31d                       "¿Cuáles de los siguientes problemas identificó en el preescolar? Mobiliario amontonado en espacios escolares a los que niñas y niños pueden acceder"
       G31e                       "¿Cuáles de los siguientes problemas identificó en el preescolar? Basura amontonada en espacios escolares a los que niñas y niños pueden acceder"
       GCOMENT                    "Si tuvo alguna duda, por favor anote el número de pregunta y su(s) comentario(s) aquí:"
       AP01                       "¿Qué cargo ocupa usted en la mesa directiva de la Asociación de Padres de Familia (APF) o Asociación Promotora de Educación Comunitaria (APEC)?"
       AP02                       "¿Desde cuándo forma parte de la mesa directiva de la Asociación de Padres de Familia (APF) o Asociación Promotora de Educación Comunitaria (APEC) de este preescolar?"
       AP03                       "¿Tiene hijas o hijos inscritas(os) en este preescolar?"
       AP04                       "En esta comunidad o colonia, ¿hay casas que tienen agua entubada o de la llave?"
       AP05                       "En esta comunidad o colonia, ¿hay casas conectadas al drenaje?"
       AP06                       "En esta comunidad o colonia, ¿hay casas que tienen energía eléctrica?"
       AP07                       "En esta comunidad o colonia, ¿se cuenta con servicio de recolección de basura?"
       AP08                       "En este preescolar, ¿cuándo iniciaron las clases en este ciclo escolar (2017-2018)?"
       AP09                       "En este preescolar, por lo regular, ¿cuántos días a la semana hay clases?"
       AP10                       "¿Cuántas horas las niñas y los niños permanecen en este preescolar en una jornada regular de clases?"
       AP11a                      "En este preescolar, ¿cómo promueve el personal de la escuela la participación de los padres de familia? Los convocan a juntas generales con todos los padres de familia"
       AP11b                      "En este preescolar, ¿cómo promueve el personal de la escuela la participación de los padres de familia? Los citan para hablar de manera individual sobre sus hijas o hijos"
       AP11c                      "En este preescolar, ¿cómo promueve el personal de la escuela la participación de los padres de familia? Los invitan a las juntas de grupos de sus hijas o hijos"
       AP11d                      "En este preescolar, ¿cómo promueve el personal de la escuela la participación de los padres de familia? Los invitan a observar una sesión de trabajo de sus hijas o hijos"
       AP11e                      "En este preescolar, ¿cómo promueve el personal de la escuela la participación de los padres de familia? Los invitan a asistir a cursos o pláticas para padres de familia"
       AP11f                      "En este preescolar, ¿cómo promueve el personal de la escuela la participación de los padres de familia? Los invitan al salón de clases para realizar actividades con sus hijas o hijos como contar cuentos, platicar de sus tradi... (ver cuestionario .pdf)"
       AP11g                      "En este preescolar, ¿cómo promueve el personal de la escuela la participación de los padres de familia? Los invitan a participar en la organización de festivales, eventos cívicos, deportivos y artísticos que se llevan a cabo en el preescolar"
       AP11h                      "En este preescolar, ¿cómo promueve el personal de la escuela la participación de los padres de familia? Los invitan a participar en actividades extraescolares como visitas a museos, excursiones, entre otras"
       AP11i                      "En este preescolar, ¿cómo promueve el personal de la escuela la participación de los padres de familia? Otra actividad"
       AP12                       "En este preescolar, ¿se invita a los padres de familia a participar en la elaboración de las reglas, normas o los acuerdos para regular los comportamientos de la comunidad escolar?"
       AP13                       "En este preescolar, ¿se invita a los padres de familia a decidir si se usa o no el uniforme escolar?"
       AP14                       "Durante este ciclo escolar (2017-2018), ¿se ha invitado a los padres de familia a decidir en qué se gastan los recursos provenientes de programas de gobierno?"
       AP15a                      "En este preescolar, ¿los padres de familia dan aportaciones o apoyan en los siguientes aspectos? Aportan materiales para las actividades educativas adicionales a la lista de útiles (libros para la biblioteca de aula, juegos d... (ver cuestionario .pdf)"
       AP15b                      "En este preescolar, ¿los padres de familia dan aportaciones o apoyan en los siguientes aspectos? Proporcionan materiales de limpieza"
       AP15c                      "En este preescolar, ¿los padres de familia dan aportaciones o apoyan en los siguientes aspectos? Proporcionan materiales de construcción para el mantenimiento del preescolar"
       AP15d                      "En este preescolar, ¿los padres de familia dan aportaciones o apoyan en los siguientes aspectos? Realizan actividades de limpieza, mantenimiento o reparación de mobiliario escolar (faenas)"
       AP15e                      "En este preescolar, ¿los padres de familia dan aportaciones o apoyan en los siguientes aspectos? Realizan actividades de asistencia o apoyo a niñas y niños en el salón de clases o dentro del preescolar (distribuir el desayun... (ver cuestionario .pdf)"
       AP15f                      "En este preescolar, ¿los padres de familia dan aportaciones o apoyan en los siguientes aspectos? Apoyan en la enseñanza del dialecto o lengua indígena"
       AP15g                      "En este preescolar, ¿los padres de familia dan aportaciones o apoyan en los siguientes aspectos? Participan en actividades para obtener dinero, a través de la venta de alimentos, la organización de kermeses, rifas u otras"
       AP15h                      "En este preescolar, ¿los padres de familia dan aportaciones o apoyan en los siguientes aspectos? Realizan trámites con el municipio o la delegación, con otras autoridades o instituciones para la mejora del preescolar"
       AP15i                      "En este preescolar, ¿los padres de familia dan aportaciones o apoyan en los siguientes aspectos? Proporcionan los recursos para la alimentación de alguna maestra (le dan de comer, le compran la despensa, le dan dinero para su comida)"
       AP15j                      "En este preescolar, ¿los padres de familia dan aportaciones o apoyan en los siguientes aspectos? Proporcionan de manera regular hospedaje a alguna maestra"
       AP16                       "En este preescolar, ¿los padres de familia aportan o apoyan con dinero al inicio o durante el ciclo escolar?"
       AP17                       "En este preescolar, ¿cómo se define el monto de las aportaciones o los apoyos de dinero que proporcionan los padres de familia cada ciclo escolar?"
       AP18                       "En este preescolar, ¿se consulta a los padres de familia en qué gastar el dinero que aportan?"
       AP19                       "Con el dinero que aportan los padres de familia, ¿se han pagado los gastos para llevar al preescolar los libros u otros materiales didácticos (gasolina, alquiler de transporte u otro)?"
       AP20a                      "Con el dinero que aportan los padres de familia, ¿se pagan los siguientes servicios en este preescolar? Agua"
       AP20b                      "Con el dinero que aportan los padres de familia, ¿se pagan los siguientes servicios en este preescolar? Luz o energía eléctrica"
       AP20c                      "Con el dinero que aportan los padres de familia, ¿se pagan los siguientes servicios en este preescolar? Servicio público de recolección de basura"
       AP20d                      "Con el dinero que aportan los padres de familia, ¿se pagan los siguientes servicios en este preescolar? Servicio de teléfono"
       AP20e                      "Con el dinero que aportan los padres de familia, ¿se pagan los siguientes servicios en este preescolar? Servicio de Internet"
       AP20f                      "Con el dinero que aportan los padres de familia, ¿se pagan los siguientes servicios en este preescolar? Predial o renta del edificio"
       AP20g                      "Con el dinero que aportan los padres de familia, ¿se pagan los siguientes servicios en este preescolar? Garrafones de agua para consumo de niñas y niños"
       AP21a                      "Con el dinero que aportan los padres de familia, ¿qué gastos o reparaciones se han pagado? La reparación, remodelación o construcción de nuevos espacios (baños, salones u otro)"
       AP21b                      "Con el dinero que aportan los padres de familia, ¿qué gastos o reparaciones se han pagado? La reparación o el mantenimiento al mobiliario escolar (sillas, mesas, escritorios, libreros, pizarrones u otro)"
       AP21c                      "Con el dinero que aportan los padres de familia, ¿qué gastos o reparaciones se han pagado? La reparación o el mantenimiento de computadoras o equipo audiovisual (televisiones, equipo de sonido, grabadoras, DVD u otro)"
       AP22a                      "Con el dinero que aportan los padres de familia, ¿se han comprado los siguientes materiales y equipos para el preescolar? Mobiliario escolar (sillas, mesas, escritorios, libreros, pizarrones u otro)"
       AP22b                      "Con el dinero que aportan los padres de familia, ¿se han comprado los siguientes materiales y equipos para el preescolar? Equipos de reproducción audiovisual (televisiones, grabadoras, reproductores de video, DVD, bocinas u otro)"
       AP22c                      "Con el dinero que aportan los padres de familia, ¿se han comprado los siguientes materiales y equipos para el preescolar? Equipos de cómputo (computadoras, cañón, impresoras u otro)"
       AP22d                      "Con el dinero que aportan los padres de familia, ¿se han comprado los siguientes materiales y equipos para el preescolar? Materiales consumibles (hojas, plumones, gises, tóner o tinta para impresoras o fotocopiadoras u otro)"
       AP22e                      "Con el dinero que aportan los padres de familia, ¿se han comprado los siguientes materiales y equipos para el preescolar? Materiales de apoyo para el trabajo escolar (libros, láminas, borradores u otro)"
       AP22f                      "Con el dinero que aportan los padres de familia, ¿se han comprado los siguientes materiales y equipos para el preescolar? Material de protección civil (botiquín escolar, extintor, alarma, señalamientos u otro)"
       AP22g                      "Con el dinero que aportan los padres de familia, ¿se han comprado los siguientes materiales y equipos para el preescolar? Materiales de limpieza para el preescolar (escobas, trapeadores, detergente u otro)"
       AP22h                      "Con el dinero que aportan los padres de familia, ¿se han comprado los siguientes materiales y equipos para el preescolar? Materiales de higiene utilizados en los baños de la escuela (jabones, papel higiénico y para las manos u otro)"
       AP23a                      "Con el dinero que aportan los padres de familia, ¿cuáles de los siguientes salarios se han llegado a pagar de forma total o parcial? El salario de alguna maestra"
       AP23b                      "Con el dinero que aportan los padres de familia, ¿cuáles de los siguientes salarios se han llegado a pagar de forma total o parcial? El salario de algún auxiliar docente o especialista que apoya a las maestras o a niñas y ni... (ver cuestionario .pdf)"
       AP23c                      "Con el dinero que aportan los padres de familia, ¿cuáles de los siguientes salarios se han llegado a pagar de forma total o parcial? El salario de algún empleado de apoyo (secretaria, intendente, vigilante u otro)"
       R01                        "En los últimos 3 meses, ¿este preescolar ha sufrido daños por sismos o temblores, huracanes, inundaciones u otros fenómenos naturales?"
       R02a                       "¿Por cuáles de los siguientes fenómenos naturales fue afectado este preescolar? Sismo o temblor"
       R02b                       "¿Por cuáles de los siguientes fenómenos naturales fue afectado este preescolar? Huracán, ciclón o lluvia torrencial"
       R02c                       "¿Por cuáles de los siguientes fenómenos naturales fue afectado este preescolar? Otro."
       R02t                       "¿Por cuáles de los siguientes fenómenos naturales fue afectado este preescolar? Especifique:"
       R03                        "¿Cuántos días se suspendieron clases debido a la afectación que tuvo el preescolar?"
       R04                        "¿Qué daños presentó o presenta este preescolar a causa de los fenómenos naturales que afectaron esta escuela?"
       R05                        "¿En este preescolar se han hecho reparaciones a partir de los daños que mencionó en la pregunta anterior?"
       R06                        "En caso de haber hecho reparaciones al preescolar, ¿me puede decir, en qué ha consistido?"
       R07                        "A partir de las reparaciones que se le hicieron a su escuela, ¿su preescolar ya cuenta con la infraestructura que tenía antes de verse afectada por el fenómeno natural?"
       WVARSTRR                   "Identificador del pseudoestrato (1 a 100) definido para el cálculo de errores estándar con el método de remuestreo BRR"
       W_FSCR1                    "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR2                    "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR3                    "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR4                    "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR5                    "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR6                    "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR7                    "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR8                    "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR9                    "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR10                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR11                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR12                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR13                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR14                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR15                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR16                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR17                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR18                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR19                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR20                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR21                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR22                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR23                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR24                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR25                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR26                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR27                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR28                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR29                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR30                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR31                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR32                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR33                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR34                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR35                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR36                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR37                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR38                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR39                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR40                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR41                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR42                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR43                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR44                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR45                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR46                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR47                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR48                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR49                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR50                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR51                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR52                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR53                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR54                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR55                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR56                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR57                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR58                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR59                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR60                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR61                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR62                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR63                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR64                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR65                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR66                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR67                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR68                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR69                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR70                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR71                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR72                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR73                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR74                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR75                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR76                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR77                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR78                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR79                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR80                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR81                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR82                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR83                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR84                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR85                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR86                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR87                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR88                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR89                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR90                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR91                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR92                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR93                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR94                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR95                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR96                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR97                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR98                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR99                   "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSCR100                  "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       VERSION                    "Versión de la base de datos"
.





/***********************************************************************
/*       Etiquetas de valores.
/*
/**********************************************************************.



VALUE LABELS
        ID_ENT
                      1      "Aguascalientes"
                      2      "Baja California"
                      3      "Baja California Sur"
                      4      "Campeche"
                      5      "Coahuila"
                      6      "Colima"
                      7      "Chiapas"
                      8      "Chihuahua"
                      9      "Ciudad de México"
                      10     "Durango"
                      11     "Guanajuato"
                      12     "Guerrero"
                      13     "Hidalgo"
                      14     "Jalisco"
                      15     "México"
                      16     "Michoacán"
                      17     "Morelos"
                      18     "Nayarit"
                      19     "Nuevo León"
                      20     "Oaxaca"
                      21     "Puebla"
                      22     "Querétaro"
                      23     "Quintana Roo"
                      24     "San Luis Potosí"
                      25     "Sinaloa"
                      26     "Sonora"
                      27     "Tabasco"
                      28     "Tamaulipas"
                      29     "Tlaxcala"
                      30     "Veracruz"
                      31     "Yucatán"
                      32     "Zacatecas"/
        ID_PREESTRATO
                      1       "Cursos Comunitarios"
                      2       "Gral Unidocente"
                      3       "Gral No Unidocente"
                      4       "Indígena Unidocente"
                      5       "Indígena No Unidocente"
                      6       "Privadas"/
        ID_TURNO
                      1      "Matutino"
                      2      "Vespertino"
                      3      "Nocturno"
                      4      "Discontinuo"
                      5      "Tiempo Completo"
                      6      "Complementario"
                      7      "Jornada Ampliada"
                      8      "Continuo"/
        D01a
        D01b
        D01c
        D01d
        D01e          1      "Sí"
                      2      "No"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D02           1      "Todos los días"
                      2      "Algunos días"
                      3      "Ninguno, no se dispone de agua en este preescolar"
                      96     "Valor Inconsistente"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D03           1      "Sí, todos los días"
                      2      "Sí, pero no todos los días"
                      3      "No"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D04           1      "Conexión al servicio público por contrato con medidor"
                      2      "Conexión al servicio público sin contrato (uso de “diablito” o puente)"
                      3      "Conexión a un edificio cercano al preescolar"
                      4      "Generador o planta de luz"
                      5      "Paneles o celdas solares"
                      6      "No sé"
                      7      "Ninguna, no hay luz en este preescolar"
                      96     "Valor Inconsistente"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D05
        D06a
        D06b
        D06c
        D06d
        D06e
        D06f
        D06g
        D06h
        D06i
        D07a
        D07b
        D07c
        D07d
        D07e
        D07f
        D07g          1      "Sí"
                      2      "No"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D08           1      "El municipio o la delegación"
                      2      "La autoridad educativa del estado (secretaría o instituto de educación del estado)"
                      3      "La supervisión escolar"
                      4      "La directora o alguna docente"
                      5      "Los padres de familia"
                      6      "Otro"
                      7      "No se han recibido"
                      8      "El capacitador tutor"
                      9      "El coordinador regional del CONAFE"
                      10     "La Líder para la Educación Comunitaria"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D08_1         1      "El municipio"
                      2      "El capacitador tutor"
                      3      "El coordinador regional del CONAFE"
                      4      "La Líder para la Educación Comunitaria"
                      5      "Los padres de familia"
                      6      "Otro"
                      7      "No se han recibido"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D08_2         1      "Antes de iniciar este ciclo escolar"
                      2      "Al inicio del ciclo escolar (en la primera semana de clases)"
                      3      "Después de iniciado el ciclo escolar (después de la primera semana de clases)"
                      4      "No me los han entregado"
                      96     "Valor Inconsistente"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D09           1      "Antes de iniciar este ciclo escolar"
                      2      "Al inicio del ciclo escolar (en la primera semana de clases)"
                      3      "Después de iniciado el ciclo escolar (después de la primera semana de clases)"
                      4      "No me los han entregado"
                      96     "Valor Inconsistente"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D10a
        D10b
        D10c
        D10d
        D10e
        D10f
        D11           1      "Sí"
                      2      "No"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D12           997    "No Administrado"
                      999    "Respuesta Omitida"/
        D13           997    "No Administrado"
                      999    "Respuesta Omitida"/
        D14           997    "No Administrado"
                      999    "Respuesta Omitida"/
        D15           997    "No Administrado"
                      999    "Respuesta Omitida"/
        D16           997    "No Administrado"
                      999    "Respuesta Omitida"/
        D17           1      "Sí"
                      2      "No"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D18a          9997   "No Administrado"
                      9999   "Respuesta Omitida"/
        D18b          9997   "No Administrado"
                      9999   "Respuesta Omitida"/
        D19           9996   "Valor Inconsistente"
                      9997   "No Administrado"
                      9999   "Respuesta Omitida"/
        D20
                      997    "No Administrado"
                      999    "Respuesta Omitida"/
        D21           1      "Sí"
                      2      "No"
                      3      "No tengo la información"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D22a
        D22b
        D22c
        D22d
        D22e
        D22f
        D22g
        D22h
        D22i
        D22j
        D22k
                      993    "No aplica por pregunta filtro"
                      996    "Valor Inconsistente"
                      997    "No Administrado"
                      999    "Respuesta Omitida"/
        D23           1      "Sí"
                      2      "No"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D24           1      "Todos"
                      2      "Más de la mitad"
                      3      "La mitad"
                      4      "Menos de la mitad"
                      5      "Ninguno"
                      93     "No aplica por pregunta filtro"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D25
        D26
                      997    "No Administrado"
                      999    "Respuesta Omitida"/
        D26_1         1      "Sólo yo"
                      2      "2"
                      3      "3"
                      4      "4 o más"
                      97     "No Administrado"
                      98     "Respuesta múltiple"
                      99     "Respuesta Omitida"/
        D27           1      "Sí"
                      2      "No"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D28           1      "Todas las docentes han sido sustituidas"
                      2      "Algunas docentes han sido sustituidas"
                      3      "Ninguna docente ha sido sustituida"
                      93     "No aplica por pregunta filtro"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D29           1      "Menos de 1 semana"
                      2      "1 semana"
                      3      "2 semanas"
                      4      "3 semanas"
                      5      "4 semanas o más"
                      6      "No sé"
                      93     "No aplica por pregunta filtro"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D30a
        D30b
        D30c
        D30d
        D31a
        D31b
        D31c
        D31d
        D31e
        D32a
        D32b
        D32c
        D32d
        D32e
        D32f          1      "Sí"
                      2      "No"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D33a
        D33b
        D33c
        D33d
        D33e
        D33f
        D33g
        D33h
        D33i
        D34           1      "Todas"
                      2      "Más de la mitad"
                      3      "La mitad"
                      4      "Menos de la mitad"
                      5      "Ninguna"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D35           1      "Menos de 3 horas"
                      2      "3 horas"
                      3      "3 horas y media"
                      4      "4 horas"
                      5      "4 horas y media"
                      6      "5 horas"
                      7      "5 horas y media"
                      8      "Más de 5 horas y media"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D36           1      "200"
                      2      "195"
                      3      "185"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D37
                      997    "No Administrado"
                      999    "Respuesta Omitida"/
        D38a
        D38b
        D38c
        D38d
        D38e
        D38f
        D38g
        D38h
        D38i
        D38j
        D38k
        D38l
                      1      "Sí"
                      2      "No"
                      96     "Valor Inconsistente"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D39
                      996    "Valor Inconsistente"
                      997     "No Administrado"
                      999    "Respuesta Omitida"/
        D40a
        D40b
        D40c
        D40d
        D40e
        D40f
        D40g
        D40h          1      "Todos"
                      2      "Más de la mitad"
                      3      "La mitad"
                      4      "Menos de la mitad"
                      5      "Ninguno"
                      6      "Esta actividad no se realiza en el preescolar"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D41
        D42a
        D42b
        D43a
        D43b
        D43c
        D43d
        D43e
        D43f
        D43g
        D43h
        D43i
        D43j
        D43k
        D43l
        D43m
        D43n
        D43o
        D43p
        D43q
        D43r          1      "Sí"
                      2      "No"
                      93     "No aplica por pregunta filtro"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D44a
        D44b
        D44c
        D44d
        D44e
        D44f
        D44g          1      "Sí"
                      2      "No"
                      3      "No sé"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D45
        D46a
        D46b
        D46c
        D46d
        D46e
        D46f          1      "Sí"
                      2      "No"
                      93     "No aplica por pregunta filtro"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D47           1      "Sí, y es suficiente para todas las niñas y los niños"
                      2      "Sí, pero no es suficiente para todas las niñas y los niños"
                      3      "No"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D48a
        D48b
        D48c
        D48d
        D48e
        D49a
        D49b
        D49c
        D49d
        D49e          1      "Sí"
                      2      "No"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D50           1      "hombre"
                      2      "mujer"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D51
                      996    "Valor Inconsistente"
                      997     "No Administrado"
                      999    "Respuesta Omitida"/
        D52           1      "Sí"
                      2      "Sí, en parte"
                      3      "No"
                      4      "No sé"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D53           1      "Sí"
                      2      "No"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D54           1      "Sí"
                      2      "Sí, en parte"
                      3      "No"
                      4      "No sé"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D55           1      "Bachillerato o preparatoria"
                      2      "Carrera Técnica o Técnico Superior"
                      3      "Normal básica sin licenciatura (antes de 1984)"
                      4      "Licenciatura"
                      5      "Maestría"
                      6      "Doctorado"
                      7      "Secundaria"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D56           1      "Licenciatura en Educación Preescolar"
                      2      "Licenciatura en Educación Preescolar para el Medio Indígena"
                      3      "Licenciatura en Educación Primaria o Primaria Indígena"
                      4      "Licenciatura relacionada con Educación Inicial, Especial o Básica"
                      5      "Otra licenciatura en educación (Pedagogía, Ciencias de la Educación, Psicopedagogía, Psicología Educativa u otra)"
                      6      "Otra licenciatura en área no educativa (Administración, Sociología u otra)"
                      7      "No tengo certificado o título de la licenciatura"
                      96     "Valor Inconsistente"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D57           1      "Licenciatura en Educación Preescolar"
                      2      "Licenciatura en Educación Preescolar para el Medio Indígena"
                      3      "Licenciatura en Educación distinta al nivel Preescolar"
                      4      "Especialidad en área educativa"
                      5      "Diplomado en área educativa"
                      6      "Maestría en área educativa"
                      7      "Doctorado en área educativa"
                      8      "Otros estudios no relacionados con la educación"
                      9      "No estoy estudiando en la actualidad"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D57_1
                      1      "Bachillerato"
                      2      "Carrera Técnica o Técnico Superior"
                      3      "Licenciatura"
                      4      "Maestría"
                      5      "Otros estudios"
                      6      "No estoy estudiando en la actualidad"
                      96     "Valor Inconsistente"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D58
        D59
        D60
        D61
                      996    "Valor Inconsistente"
                      997    "No Administrado"
                      999    "Respuesta Omitida"/
        D62           1      "Directora con clave y base (escuela pública)"
                      2      "Directora interina (escuela pública)"
                      3      "Directora comisionada (escuela pública)"
                      4      "Docente encargada de la dirección (escuela pública)"
                      5      "Directora contratada por tiempo determinado, honorarios o eventual (escuela pública o privada)"
                      6      "Directora contratada por tiempo indefinido (escuela privada)"
                      7      "Directora dueña de la escuela (escuela privada)"
                      8      "Otro"
                      9      "No sé"
                      96     "Valor Inconsistente"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        D63
        D64
        D65a
        D65b
        D65c
        D65d
        D65e
        D65f
        D65g
        D65h
        D65i
        D65j
        D66
        D67a
        D67b
        D67c
        D67d
        D67e
        D67f
        D67g
        D67h
        D67i
        D67j
        D67k          1      "Sí"
                      2      "No"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        G01           1      "Sí, es una construcción diseñada para ser un preescolar"
                      2      "No, es un espacio adaptado (era una casa, bodega, local, tejaban u otro)"
                      3      "No, es un aula móvil"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        G02           1      "Sí"
                      2      "No"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        G03           1      "Sí, completo: Todo el terreno del preescolar está delimitado por su propia barda o cerco"
                      2      "Sí, incompleto: El terreno cuenta con barda o cerco, pero le falta algún tramo que puede d... (ver cuestionario .pdf)"
                      3      "No necesita: El edificio del preescolar se encuentra delimitado por otros inmuebles o se u... (ver cuestionario .pdf)"
                      4      "No tiene"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        G04a
        G04b
        G04c
        G04d
        G04e
                      1      "Sí"
                      2      "No"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        G05a
        G05b
        G05c
                      1      "Sí, en todas las áreas"
                      2      "Sí, sólo en algunas de las áreas"
                      3      "No existen"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        G06a
        G06b
        G06c
        G06d
        G06e
        G06f
        G06g
        G06h
        G06i
                      1      "Sí"
                      2      "No"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        G07a
        G07b
        G07c
        G07d
                      1      "Sí"
                      2      "No"
                      3      "No existe el espacio"
                      96     "Valor Inconsistente"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        G08a
        G08b
        G08c
        G08d
        G08e
                      1      "Limpio"
                      2      "Sucio"
                      3      "Muy sucio"
                      4      "No existe el espacio"
                      96     "Valor Inconsistente"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        G09
        G10a
        G10b
        G10c
        G11
                      1      "Sí"
                      2      "No"
                      93     "No aplica por pregunta filtro"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        G12           997    "No Administrado"
                      999    "Respuesta Omitida"/
        G13           1      "Todos"
                      2      "Más de la mitad"
                      3      "La mitad"
                      4      "Menos de la mitad"
                      5      "Ninguno"
                      96     "Valor Inconsistente"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        G14           1      "Ladrillo, tabique o block"
                      2      "Concreto"
                      3      "Adobe"
                      4      "Tablaroca o prefabricado"
                      5      "Lámina"
                      6      "Madera"
                      7      "Otro"
                      8      "No tiene(n) pared(es) o muro(s)"
                      96     "Valor Inconsistente"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        G15           1      "Todos"
                      2      "Más de la mitad"
                      3      "La mitad"
                      4      "Menos de la mitad"
                      5      "Ninguno"
                      96     "Valor Inconsistente"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        G16           1      "Losa de concreto"
                      2      "Tabique, ladrillo, bovedilla, madera o teja"
                      3      "Panel metálico (con láminas acanaladas de acero)"
                      4      "Lámina de asbesto, metálica o de plástico"
                      5      "Lámina de cartón"
                      6      "Palma o carrizo"
                      7      "Otro"
                      8      "No tienen techo"
                      96     "Valor Inconsistente"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        G17           1      "Concreto con algún recubrimiento"
                      2      "Concreto sin recubrimiento"
                      3      "Tierra o materiales removibles (arena)"
                      96     "Valor Inconsistente"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        G18           1      "Limpios: Los salones de clases están aseados y libres de polvo o basura acumulada"
                      2      "Sucios: Los salones de clases presentan algunas manchas, polvo o basura acumulada"
                      3      "Muy sucios: Los salones de clases presentan manchas, mucho polvo o basura acumulada"
                      96     "Valor Inconsistente"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        G19           1      "Sí, hay agua de la llave"
                      2      "Sí, pero está en tambos u otro tipo de contenedor"
                      3      "No"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        G20
                      996    "Valor Inconsistente"
                      997    "No Administrado"
                      999    "Respuesta Omitida"/
        G21           997    "No Administrado"
                      999    "Respuesta Omitida"/
        G22           997    "No Administrado"
                      999    "Respuesta Omitida"/
        G23           997    "No Administrado"
                      999    "Respuesta Omitida"/
        G24           1      "Sí están separadas por sexo"
                      2      "No están separadas por sexo"
                      3      "No hay servicios sanitarios para niñas y niños"
                      96     "Valor Inconsistente"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        G25           1      "Sí, en el tanque de las tazas, excusados o inodoros"
                      2      "Sí, en tambos u otro tipo de contenedor"
                      3      "No hay agua para las tazas, excusados o inodoros"
                      4      "No necesita, tiene letrina u hoyo negro"
                      5      "No hay servicios sanitarios (como tazas, inodoros, excusados o letrinas)"
                      96     "Valor Inconsistente"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        G26           1      "Desagüe al aire libre (a estanque, río, campo, riego de áreas verdes)"
                      2      "Hoyo negro"
                      3      "Fosa séptica sin instalación hidráulica"
                      4      "Letrina seca"
                      5      "Instalación hidráulica (con servicio de agua y conexión al drenaje)"
                      6      "No hay servicios sanitarios (como tazas, inodoros, excusados o letrinas)"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        G27
        G28
                      1      "Sí"
                      2      "No"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        G29           1      "Limpio: El servicio sanitario está aseado y libre de polvo o basura acumulada"
                      2      "Sucio: El servicio sanitario presenta algunas manchas, polvo o basura acumulada"
                      3      "Muy sucio: El servicio sanitario presenta manchas, mucho polvo o basura acumulada"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        G30a
        G30b
        G30c
        G30d
        G30e
        G30f
        G30g
        G30h
        G30i
        G30j
                      1      "Sí"
                      2      "No"
                      3      "No aplica"
                      96     "Valor Inconsistente"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        G31a
        G31b
        G31c
        G31d
        G31e
                      1      "Sí"
                      2      "No"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        AP01          1      "Presidente"
                      2      "Vicepresidente"
                      3      "Secretario"
                      4      "Tesorero"
                      5      "Vocal"
                      6      "Otro cargo"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        AP02          1      "A partir de este ciclo escolar"
                      2      "Desde el ciclo escolar anterior"
                      3      "Hace 2 ciclos escolares"
                      4      "Hace más de 2 ciclos escolares"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        AP03
        AP04
        AP05
        AP06
        AP07          1      "Sí"
                      2      "No"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        AP08          1      "El día marcado en el calendario oficial"
                      2      "Después del día marcado en el calendario oficial, pero durante la primera semana"
                      3      "Una semana después del día marcado en el calendario oficial"
                      4      "Dos semanas después del día marcado en el calendario oficial"
                      5      "Tres semanas o más después del día marcado en el calendario oficial"
                      6      "No sé"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        AP09          1      "Menos de 5 días"
                      2      "5 días"
                      3      "Más de 5 días"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        AP10          1      "Menos de 3 horas"
                      2      "3 horas"
                      3      "3 horas y media"
                      4      "4 horas"
                      5      "4 horas y media"
                      6      "5 horas"
                      7      "Más de 5 horas"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        AP11a
        AP11b
        AP11c
        AP11d
        AP11e
        AP11f
        AP11g
        AP11h
        AP11i
        AP12
        AP13          1      "Sí"
                      2      "No"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        AP14          1      "Sí"
                      2      "No"
                      3      "No sé"
                      4      "No hay recursos provenientes de programas de gobierno"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        AP15a
        AP15b
        AP15c
        AP15d
        AP15e
        AP15f
        AP15g
        AP15h
        AP15i
        AP15j
        AP16          1      "Sí"
                      2      "No"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        AP17          1      "Lo decide la mesa directiva de la Asociación de Padres de Familia (APF) o la Asociación Pr... (ver cuestionario .pdf)"
                      2      "La directora decide cuánto dinero debe dar cada familia"
                      3      "En asamblea los padres deciden cuánto dinero debe dar cada familia"
                      4      "Entre padres de familia, directora y maestras se acuerda cuánto dinero se debe dar por niña o niño o familia"
                      5      "No sé"
                      6      "De otra forma"
                      93     "No aplica por pregunta filtro"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        AP18          1      "Sí"
                      2      "No"
                      93     "No aplica por pregunta filtro"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        AP19
        AP20a
        AP20b
        AP20c
        AP20d
        AP20e
        AP20f
        AP20g
        AP21a
        AP21b
        AP21c
        AP22a
        AP22b
        AP22c
        AP22d
        AP22e
        AP22f
        AP22g
        AP22h
        AP23a
        AP23b
        AP23c         1      "Sí"
                      2      "No"
                      3      "No sé"
                      93     "No aplica por pregunta filtro"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        R01
        R02a
        R02b
        R02c
                      1      "Sí"
                      2      "No"
                      93     "No aplica por pregunta filtro"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        R02t
                      '93'   "No aplica por pregunta filtro"
                      '96'   "Valor Inconsistente"
                      '98'   "Respuesta Múltiple"
                      '99'   "Respuesta Omitida"/
        R03
                      993    "No aplica por pregunta filtro"
                      997    "No Administrado"
                      999    "Respuesta Omitida"/
        R04
                      '93'   "No aplica por pregunta filtro"
                      '98'   "Respuesta Múltiple"
                      '99'   "Respuesta Omitida"/
        R05
                      1      "Sí"
                      2      "No"
                      93     "No aplica por pregunta filtro"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
        R06
                      '93'   "No aplica por pregunta filtro"
                      '98'   "Respuesta Múltiple"
                      '99'   "Respuesta Omitida"/
        R07           1      "Sí, y quedó mejor que como estaba"
                      2      "Sí, y quedó igual que como estaba"
                      3      "No, le faltan varias reparaciones para quedar como estaba"
                      93     "No aplica por pregunta filtro"
                      97     "No Administrado"
                      98     "Respuesta Múltiple"
                      99     "Respuesta Omitida"/
.

EXECUTE.

/***********************************************************************
/* Declaración de valores Perdidos.
/*
/**********************************************************************.

    MISSING VALUES D01a TO D11 (92 TO 99).
    MISSING VALUES D12 TO D16 (992 TO 999).
    MISSING VALUES D17 (92 TO 99).
    MISSING VALUES D18a TO D19 (9992 TO 9999).
    MISSING VALUES D20 (992 TO 999).
    MISSING VALUES D21 (92 TO 99).
    MISSING VALUES D22a TO D22k (992 TO 999).
    MISSING VALUES D23 TO D24 (92 TO 99).
    MISSING VALUES D25 TO D26 (992 TO 999).
    MISSING VALUES D26_1 TO D36 (92 TO 99).
    MISSING VALUES D37 (992 TO 999).
    MISSING VALUES D38a TO D38l (92 TO 99).
    MISSING VALUES D39 (992 TO 999).
    MISSING VALUES D40a TO D50 (92 TO 99).
    MISSING VALUES D51 (992 TO 999).
    MISSING VALUES D52 TO D57_1 (92 TO 99).
    MISSING VALUES D58 TO D61 (992 TO 999).
    MISSING VALUES D62 TO D67k (92 TO 99).
    MISSING VALUES G01 TO G11 (92 TO 99).
    MISSING VALUES G12 (992 TO 999).
    MISSING VALUES G13 TO G19 (92 TO 99).
    MISSING VALUES G20 TO G23 (992 TO 999).
    MISSING VALUES G24 TO G31e (92 TO 99).
    MISSING VALUES AP01 TO AP23c (92 TO 99).
    MISSING VALUES R01 TO R02c (92 TO 99).
    MISSING VALUES R02t ('93','96','99').
    MISSING VALUES R03 (92 TO 999).
    MISSING VALUES R04 ('93','99').
    MISSING VALUES R05 (92 TO 99).
    MISSING VALUES R06 ('93','99').
    MISSING VALUES R07 (92 TO 99).
   EXECUTE.



